@@ -116,6 +116,7 @@ def generate_brownie_constructor_function(
             ),
             cst.parse_statement("self.address = deployed_contract.address"),
             cst.parse_statement("self.contract = deployed_contract"),
+            cst.parse_statement("return deployed_contract.tx"),
         ]
     )
 
@@ -202,6 +203,15 @@ def generate_brownie_contract_function(func_object: Dict[str, Any]) -> cst.Funct
             f"return self.contract.{func_raw_name}({','.join(param_names)})"
         )
     else:
+
+        func_params.append(
+            cst.Param(
+                name=cst.Name(value="block_number"),
+                annotation=make_annotation(["str", "int"], optional=True),
+                default=cst.SimpleString(value='"latest"'),
+            )
+        )
+        param_names.append("block_identifier=block_number")
         proxy_call_code = (
             f"return self.contract.{func_raw_name}.call({','.join(param_names)})"
         )
@@ -403,6 +413,7 @@ def generate_deploy_handler(
     function_body_raw.append(method_call_result_statement)
 
     function_body_raw.append(cst.parse_statement("print(result)"))
+    function_body_raw.append(cst.parse_statement("print(result.info())"))
 
     function_body = cst.IndentedBlock(body=function_body_raw)
 
@@ -536,6 +547,15 @@ def generate_cli_handler(
                 value=cst.Name(value="transaction_config"),
             )
         )
+    else:
+        call_args.append(
+            cst.Arg(
+                keyword=cst.Name(value="block_number"),
+                value=cst.Attribute(
+                    attr=cst.Name(value="block_number"), value=cst.Name("args")
+                ),
+            )
+        )
     method_call = cst.Call(
         func=cst.Attribute(
             attr=cst.Name(value=spec["method"]),
@@ -555,6 +575,17 @@ def generate_cli_handler(
 
     function_body_raw.append(cst.parse_statement("print(result)"))
 
+    if requires_transaction:
+        verbose_print = cst.If(
+            test=cst.parse_expression("args.verbose"),
+            body=cst.IndentedBlock(
+                body=[
+                    cst.parse_statement("print(result.info())"),
+                ]
+            ),
+        )
+        function_body_raw.append(verbose_print)
+
     function_body = cst.IndentedBlock(body=function_body_raw)
 
     function_def = cst.FunctionDef(
@@ -592,7 +623,14 @@ def generate_add_default_arguments() -> cst.FunctionDef:
                 test=cst.UnaryOperation(
                     operator=cst.Not(), expression=cst.Name(value="transact")
                 ),
-                body=cst.parse_statement("return"),
+                body=cst.IndentedBlock(
+                    body=[
+                        cst.parse_statement(
+                            'parser.add_argument("--block-number", required=False, type=int, help="Call at the given block number, defaults to latest")'
+                        ),
+                        cst.parse_statement("return"),
+                    ]
+                ),
             ),
             cst.parse_statement(
                 'parser.add_argument("--sender", required=True, help="Path to keystore file for transaction sender")'
@@ -618,6 +656,9 @@ def generate_add_default_arguments() -> cst.FunctionDef:
             cst.parse_statement(
                 'parser.add_argument("--value", default=None, help="Value of the transaction in wei(optional)")'
             ),
+            cst.parse_statement(
+                'parser.add_argument("--verbose", action="store_true", help="Print verbose output")'
+            ),
         ],
     )
     function_def = cst.FunctionDef(
